@@ -1,16 +1,9 @@
-$:.unshift File.join(File.dirname(__FILE__), "..", "lib")
-
-require 'test/unit'
-require 'rubygems'
-require 'mechanize'
-require 'test_includes'
+require File.dirname(__FILE__) + "/helper"
 
 class TestBadLinks < Test::Unit::TestCase
-  include TestMethods
-
   def setup
     @agent = WWW::Mechanize.new
-    @page = @agent.get("http://localhost:#{PORT}/tc_bad_links.html")
+    @page = @agent.get("http://localhost/tc_bad_links.html")
   end
 
   def test_space_in_link
@@ -24,7 +17,7 @@ class TestBadLinks < Test::Unit::TestCase
   def test_space_in_url
     page = nil
     assert_nothing_raised do
-      page = @agent.get("http://localhost:#{PORT}/tc_bad_links.html ")
+      page = @agent.get("http://localhost/tc_bad_links.html ")
     end
     assert_match(/tc_bad_links.html$/, @agent.history.last.uri.to_s)
     assert_equal(2, @agent.history.length)
