@@ -1,17 +1,9 @@
-$:.unshift File.join(File.dirname(__FILE__), "..", "lib")
-
-require 'test/unit'
-require 'rubygems'
-require 'mechanize'
-require 'test_includes'
-require 'logger'
+require File.dirname(__FILE__) + "/helper"
 
 class TestFormAction < Test::Unit::TestCase
-  include TestMethods
-
   def setup
     @agent = WWW::Mechanize.new
-    @page  = @agent.get("http://localhost:#{PORT}/tc_form_action.html")
+    @page  = @agent.get("http://localhost/tc_form_action.html")
   end
 
   def test_post_encoded_action
@@ -20,7 +12,7 @@ class TestFormAction < Test::Unit::TestCase
     }
     assert_equal('/form_post?a=b&b=c', form.action)
     page = form.submit
-    assert_equal("http://localhost:#{PORT}/form_post?a=b&b=c", page.uri.to_s)
+    assert_equal("http://localhost/form_post?a=b&b=c", page.uri.to_s)
   end
 
   def test_get_encoded_action
@@ -29,7 +21,7 @@ class TestFormAction < Test::Unit::TestCase
     }
     assert_equal('/form_post?a=b&b=c', form.action)
     page = form.submit
-    assert_equal("http://localhost:#{PORT}/form_post?first_name=Aaron", page.uri.to_s)
+    assert_equal("http://localhost/form_post?first_name=Aaron", page.uri.to_s)
   end
 
   def test_post_nonencoded_action
@@ -38,7 +30,7 @@ class TestFormAction < Test::Unit::TestCase
     }
     assert_equal('/form_post?a=b&b=c', form.action)
     page = form.submit
-    assert_equal("http://localhost:#{PORT}/form_post?a=b&b=c", page.uri.to_s)
+    assert_equal("http://localhost/form_post?a=b&b=c", page.uri.to_s)
   end
 
   def test_post_pound_sign
@@ -47,6 +39,6 @@ class TestFormAction < Test::Unit::TestCase
     }
     assert_equal('/form_post#1', form.action)
     page = form.submit
-    assert_equal("http://localhost:#{PORT}/form_post#1", page.uri.to_s)
+    assert_equal("http://localhost/form_post#1", page.uri.to_s)
   end
 end
