@@ -1,17 +1,25 @@
-$:.unshift File.join(File.dirname(__FILE__), "..", "lib")
-
-require 'test/unit'
-require 'rubygems'
-require 'mechanize'
-require 'test_includes'
+require File.dirname(__FILE__) + "/helper"
 
 class LinksMechTest < Test::Unit::TestCase
-  include TestMethods
-
   def setup
     @agent = WWW::Mechanize.new
   end
 
+  def test_unsupported_link_types
+    page = @agent.get("http://google.com/tc_links.html")
+    link = page.links.text('javascript link').first
+    assert_raise(WWW::Mechanize::UnsupportedSchemeError) {
+      link.click
+    }
+
+    @agent.scheme_handlers['javascript'] = lambda { |link, page|
+      URI.parse('http://localhost/tc_links.html')
+    }
+    assert_nothing_raised {
+      link.click
+    }
+  end
+
   def test_base
     page = @agent.get("http://google.com/tc_base_link.html")
     page = page.links.first.click
@@ -19,7 +27,7 @@ class LinksMechTest < Test::Unit::TestCase
   end
 
   def test_find_meta
-    page = @agent.get("http://localhost:#{PORT}/find_link.html")
+    page = @agent.get("http://localhost/find_link.html")
     assert_equal(3, page.meta.length)
     assert_equal(%w{
       http://www.drphil.com/
@@ -29,12 +37,12 @@ class LinksMechTest < Test::Unit::TestCase
   end
 
   def test_find_link
-    page = @agent.get("http://localhost:#{PORT}/find_link.html")
+    page = @agent.get("http://localhost/find_link.html")
     assert_equal(18, page.links.length)
   end
 
   def test_alt_text
-    page = @agent.get("http://localhost:#{PORT}/alt_text.html")
+    page = @agent.get("http://localhost/alt_text.html")
     assert_equal(5, page.links.length)
     assert_equal(1, page.meta.length)
 
@@ -48,27 +56,27 @@ class LinksMechTest < Test::Unit::TestCase
 
   def test_click_link
     @agent.user_agent_alias = 'Mac Safari'
-    page = @agent.get("http://localhost:#{PORT}/frame_test.html")
+    page = @agent.get("http://localhost/frame_test.html")
     link = page.links.text("Form Test")
     assert_not_nil(link)
     assert_equal('Form Test', link.text)
     page = @agent.click(link)
-    assert_equal("http://localhost:#{PORT}/form_test.html",
+    assert_equal("http://localhost/form_test.html",
       @agent.history.last.uri.to_s)
   end
 
   def test_click_method
-    page = @agent.get("http://localhost:#{PORT}/frame_test.html")
+    page = @agent.get("http://localhost/frame_test.html")
     link = page.links.text("Form Test")
     assert_not_nil(link)
     assert_equal('Form Test', link.text)
     page = link.click
-    assert_equal("http://localhost:#{PORT}/form_test.html",
+    assert_equal("http://localhost/form_test.html",
       @agent.history.last.uri.to_s)
   end
 
   def test_find_bold_link
-    page = @agent.get("http://localhost:#{PORT}/tc_links.html")
+    page = @agent.get("http://localhost/tc_links.html")
     link = page.links.text(/Bold Dude/)
     assert_equal(1, link.length)
     assert_equal('Bold Dude', link.first.text)
@@ -87,19 +95,19 @@ class LinksMechTest < Test::Unit::TestCase
   end
 
   def test_link_with_encoded_space
-    page = @agent.get("http://localhost:#{PORT}/tc_links.html")
+    page = @agent.get("http://localhost/tc_links.html")
     link = page.links.text('encoded space').first
     page = @agent.click link
   end
 
   def test_link_with_space
-    page = @agent.get("http://localhost:#{PORT}/tc_links.html")
+    page = @agent.get("http://localhost/tc_links.html")
     link = page.links.text('not encoded space').first
     page = @agent.click link
   end
 
   def test_link_with_unusual_characters
-    page = @agent.get("http://localhost:#{PORT}/tc_links.html")
+    page = @agent.get("http://localhost/tc_links.html")
     link = page.links.text('unusual characters').first
     assert_nothing_raised { @agent.click link }
   end
