@@ -1,16 +1,21 @@
-$:.unshift File.join(File.dirname(__FILE__), "..", "lib")
-
-require 'test/unit'
-require 'rubygems'
-require 'mechanize'
-require 'test_includes'
+require File.dirname(__FILE__) + "/helper"
 
 class UploadMechTest < Test::Unit::TestCase
-  include TestMethods
-
   def setup
     @agent = WWW::Mechanize.new
-    @page = @agent.get("http://localhost:#{PORT}/file_upload.html")
+    @page = @agent.get("http://localhost/file_upload.html")
+  end
+
+  def test_upload_with_post_param
+    page = @agent.post('http://localhost/file_upload', {
+      :name       => 'Some file',
+      :userfile1  => File.open(__FILE__)
+    })
+    assert_match(
+      "Content-Disposition: form-data; name=\"userfile1\"; filename=\"#{File.basename(__FILE__)}\"",
+      page.body
+    )
+    assert page.body.length > File.read(__FILE__).length
   end
 
   def test_form_enctype
